tiled.queries.StructureFamily
=============================

.. currentmodule:: tiled.queries

.. autoclass:: StructureFamily

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StructureFamily.__init__
      ~StructureFamily.decode
      ~StructureFamily.encode
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StructureFamily.value
   
   